@@ -1,7 +1,7 @@
 package Business::ID::SIM;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2019-10-15'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use warnings;
@@ -11,7 +11,7 @@ use DateTime;
 
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT = qw(parse_sim);
+our @EXPORT_OK = qw(parse_sim);
 
 # legend: S = lack of samples
 
@@ -96,7 +96,7 @@ Business::ID::SIM - Validate Indonesian driving license number (nomor SIM)
 
 =head1 VERSION
 
-This document describes version 0.07 of Business::ID::SIM (from Perl distribution Business-ID-SIM), released on 2015-09-03.
+This document describes version 0.08 of Business::ID::SIM (from Perl distribution Business-ID-SIM), released on 2019-10-15.
 
 =head1 SYNOPSIS
 
@@ -123,10 +123,16 @@ in the SIM number and all SIM's have the same number.
 =head1 FUNCTIONS
 
 
-=head2 parse_sim(%args) -> [status, msg, result, meta]
+=head2 parse_sim
+
+Usage:
+
+ parse_sim(%args) -> [status, msg, payload, meta]
 
 Validate Indonesian driving license number (nomor SIM).
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -142,7 +148,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -170,7 +176,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
